pub enum CoreResourceMsg {
Show 28 variants
Fetch(RequestBuilder, FetchChannels),
Cancel(Vec<RequestId>),
FetchRedirect(RequestBuilder, ResponseInit, IpcSender<FetchResponseMsg>),
SetCookieForUrl(ServoUrl, Serde<Cookie<'static>>, CookieSource),
SetCookiesForUrl(ServoUrl, Vec<Serde<Cookie<'static>>>, CookieSource),
SetCookieForUrlAsync(CookieStoreId, ServoUrl, Serde<Cookie<'static>>, CookieSource),
GetCookiesForUrl(ServoUrl, IpcSender<Option<String>>, CookieSource),
GetCookiesDataForUrl(ServoUrl, IpcSender<Vec<Serde<Cookie<'static>>>>, CookieSource),
GetCookieDataForUrlAsync(CookieStoreId, ServoUrl, Option<String>),
GetAllCookieDataForUrlAsync(CookieStoreId, ServoUrl, Option<String>),
DeleteCookiesForSites(Vec<String>, GenericSender<()>),
DeleteCookies(Option<ServoUrl>, Option<IpcSender<()>>),
DeleteCookie(ServoUrl, String),
DeleteCookieAsync(CookieStoreId, ServoUrl, String),
NewCookieListener(CookieStoreId, IpcSender<CookieAsyncResponse>, ServoUrl),
RemoveCookieListener(CookieStoreId),
ListCookies(GenericSender<Vec<SiteDescriptor>>),
GetHistoryState(HistoryStateId, IpcSender<Option<Vec<u8>>>),
SetHistoryState(HistoryStateId, Vec<u8>),
RemoveHistoryStates(Vec<HistoryStateId>),
GetCacheEntries(GenericSender<Vec<CacheEntryDescriptor>>),
ClearCache(Option<GenericSender<()>>),
NetworkMediator(IpcSender<CustomResponseMediator>, ImmutableOrigin),
ToFileManager(FileManagerThreadMsg),
StorePreloadedResponse(PreloadId, Response),
TotalSizeOfInFlightKeepAliveRecords(PipelineId, GenericSender<u64>),
Exit(GenericOneshotSender<()>),
CollectMemoryReport(ReportsChan),
}Variants
Fetch(RequestBuilder, FetchChannels)
Cancel(Vec<RequestId>)
FetchRedirect(RequestBuilder, ResponseInit, IpcSender<FetchResponseMsg>)
Initiate a fetch in response to processing a redirection
SetCookieForUrl(ServoUrl, Serde<Cookie<'static>>, CookieSource)
Store a cookie for a given originating URL
SetCookiesForUrl(ServoUrl, Vec<Serde<Cookie<'static>>>, CookieSource)
Store a set of cookies for a given originating URL
SetCookieForUrlAsync(CookieStoreId, ServoUrl, Serde<Cookie<'static>>, CookieSource)
GetCookiesForUrl(ServoUrl, IpcSender<Option<String>>, CookieSource)
Retrieve the stored cookies for a given URL
GetCookiesDataForUrl(ServoUrl, IpcSender<Vec<Serde<Cookie<'static>>>>, CookieSource)
Get a cookie by name for a given originating URL
GetCookieDataForUrlAsync(CookieStoreId, ServoUrl, Option<String>)
GetAllCookieDataForUrlAsync(CookieStoreId, ServoUrl, Option<String>)
DeleteCookiesForSites(Vec<String>, GenericSender<()>)
DeleteCookies(Option<ServoUrl>, Option<IpcSender<()>>)
This currently is used by unit tests and WebDriver only.
When url is None, this clears cookies across all origins.
DeleteCookie(ServoUrl, String)
DeleteCookieAsync(CookieStoreId, ServoUrl, String)
NewCookieListener(CookieStoreId, IpcSender<CookieAsyncResponse>, ServoUrl)
RemoveCookieListener(CookieStoreId)
ListCookies(GenericSender<Vec<SiteDescriptor>>)
GetHistoryState(HistoryStateId, IpcSender<Option<Vec<u8>>>)
Get a history state by a given history state id
SetHistoryState(HistoryStateId, Vec<u8>)
Set a history state for a given history state id
RemoveHistoryStates(Vec<HistoryStateId>)
Removes history states for the given ids
GetCacheEntries(GenericSender<Vec<CacheEntryDescriptor>>)
Gets a list of origin descriptors derived from entries in the cache
ClearCache(Option<GenericSender<()>>)
Clear the network cache.
NetworkMediator(IpcSender<CustomResponseMediator>, ImmutableOrigin)
Send the service worker network mediator for an origin to CoreResourceThread
ToFileManager(FileManagerThreadMsg)
Message forwarded to file manager’s handler
StorePreloadedResponse(PreloadId, Response)
TotalSizeOfInFlightKeepAliveRecords(PipelineId, GenericSender<u64>)
Exit(GenericOneshotSender<()>)
Break the load handler loop, send a reply when done cleaning up local resources and exit
CollectMemoryReport(ReportsChan)