pub struct ServoCipherSuite(pub CipherSuite);Tuple Fields
0: CipherSuiteTrait Implementations
Sourceimpl Clone for ServoCipherSuite
impl Clone for ServoCipherSuite
Sourcefn clone(&self) -> ServoCipherSuite
fn clone(&self) -> ServoCipherSuite
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ServoCipherSuite
impl Debug for ServoCipherSuite
Sourceimpl<'de> Deserialize<'de> for ServoCipherSuite
impl<'de> Deserialize<'de> for ServoCipherSuite
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl MallocSizeOf for ServoCipherSuite
impl MallocSizeOf for ServoCipherSuite
Sourcefn size_of(&self, _: &mut MallocSizeOfOps) -> usize
fn size_of(&self, _: &mut MallocSizeOfOps) -> usize
Measure the heap usage of all descendant heap-allocated structures, but
not the space taken up by the value itself.
Sourceimpl PartialEq for ServoCipherSuite
impl PartialEq for ServoCipherSuite
Sourcefn eq(&self, other: &ServoCipherSuite) -> bool
fn eq(&self, other: &ServoCipherSuite) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ServoCipherSuite
impl Serialize for ServoCipherSuite
impl StructuralPartialEq for ServoCipherSuite