pub struct ServoProtocolVersion(pub ProtocolVersion);Tuple Fields
0: ProtocolVersionTrait Implementations
Sourceimpl Clone for ServoProtocolVersion
impl Clone for ServoProtocolVersion
Sourcefn clone(&self) -> ServoProtocolVersion
fn clone(&self) -> ServoProtocolVersion
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ServoProtocolVersion
impl Debug for ServoProtocolVersion
Sourceimpl<'de> Deserialize<'de> for ServoProtocolVersion
impl<'de> Deserialize<'de> for ServoProtocolVersion
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl MallocSizeOf for ServoProtocolVersion
impl MallocSizeOf for ServoProtocolVersion
Sourcefn size_of(&self, _: &mut MallocSizeOfOps) -> usize
fn size_of(&self, _: &mut MallocSizeOfOps) -> usize
Measure the heap usage of all descendant heap-allocated structures, but
not the space taken up by the value itself.
Sourceimpl PartialEq for ServoProtocolVersion
impl PartialEq for ServoProtocolVersion
Sourcefn eq(&self, other: &ServoProtocolVersion) -> bool
fn eq(&self, other: &ServoProtocolVersion) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ServoProtocolVersion
impl Serialize for ServoProtocolVersion
impl StructuralPartialEq for ServoProtocolVersion